@@ -1,21 +1,6 @@
-//
-//  Copyright (C) 1998-2005 Matthias Hoelzer
-//  email:  hoelzer@physik.uni-wuerzburg.de
-//
-//  This program is free software; you can redistribute it and/or modify
-//  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
-//  (at your option) any later version.
-//
-//  This program is distributed in the hope that it will be useful,
-//  but WITHOUT ANY WARRANTY; without even the7 implied warranty of
-//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//  GNU General Public License for more details.
-//
-//  You should have received a copy of the GNU General Public License
-//  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-//
+//  SPDX-FileCopyrightText: 1998-2005 Matthias Hoelzer <hoelzer@physik.uni-wuerzburg.de>
+//  SPDX-License-Identifier: GPL-2.0-or-later
+
 #include "klistboxdialog.h"
 
 #include <QLabel>
@@ -26,7 +11,7 @@ KListBoxDialog::KListBoxDialog(const QString &text, QWidget *parent)
     : QDialog(parent)
 {
     setModal(true);
-    QVBoxLayout *vLayout = new QVBoxLayout(this);
+    auto *vLayout = new QVBoxLayout(this);
 
     label = new QLabel(text, this);
     vLayout->addWidget(label);
@@ -36,7 +21,7 @@ KListBoxDialog::KListBoxDialog(const QString &text, QWidget *parent)
     vLayout->addWidget(table);
     table->setFocus();
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+    auto *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
     vLayout->addWidget(buttonBox);
 
     connect(buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
